.. image:: https://travis-ci.org/gocept/zodb.py3migrate.svg?branch=master
        :target: https://travis-ci.org/gocept/zodb.py3migrate.svg

.. image:: https://readthedocs.org/projects/zodbpy3migrate/badge/?version=latest
        :target: https://zodbpy3migrate.readthedocs.io
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/zodb.py3migrate.svg
        :target: https://pypi.org/project/zodb.py3migrate/
        :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/zodb.py3migrate.svg
        :target: https://pypi.org/project/zodb.py3migrate/
        :alt: Python versions


===================================
zodb.py3migrate - ZODB and Python 3
===================================

If you have a ZODB_ database written using Python 2.x this package helps you to
get your database ready for using it with Python 3. It is able to:

* display objects which need to be converted,

* do most of the the conversion for you,

* and switch the database file to be readable in a process running Python 3.

This package is compatible with Python version 2.7.

The documentation is at https://zodbpy3migrate.readthedocs.io.

.. _ZODB : http://zodb.org
